@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2009, Live Networks, Inc.  All rights reserved
 //	Help by Carlo Bonamico to get working for Windows
 // Delay queue
 // Implementation
@@ -193,6 +193,11 @@ DelayQueueEntry* DelayQueue::findEntryByToken(long tokenToFind) {
 void DelayQueue::synchronize() {
   // First, figure out how much time has elapsed since the last sync:
   EventTime timeNow = TimeNow();
+  if (timeNow < fLastSyncTime) {
+    // The system clock has apparently gone back in time; reset our sync time and return:
+    fLastSyncTime  = timeNow;
+    return;
+  }
   DelayInterval timeSinceLastSync = timeNow - fLastSyncTime;
   fLastSyncTime = timeNow;
 
@@ -217,8 +222,4 @@ EventTime TimeNow() {
   return EventTime(tvNow.tv_sec, tvNow.tv_usec);
 }
 
-DelayInterval TimeRemainingUntil(const EventTime& futureEvent) {
-  return futureEvent - TimeNow();
-}
-
 const EventTime THE_END_OF_TIME(INT_MAX);
