@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.
 // An object that redirects one or more RTP/RTCP streams - forming a single
 // multimedia session - into a 'Darwin Streaming Server' (for subsequent
 // reflection to potentially arbitrarily many remote RTSP clients).
@@ -73,7 +73,7 @@ DarwinInjector::DarwinInjector(UsageEnvironment& env,
     fApplicationName(strDup(applicationName)), fVerbosityLevel(verbosityLevel),
     fRTSPClient(NULL), fSubstreamSDPSizes(0),
     fHeadSubstream(NULL), fTailSubstream(NULL), fSession(NULL), fLastTrackId(0) {
-} 
+}
 
 DarwinInjector::~DarwinInjector() {
   if (fSession != NULL) { // close down and delete the session
@@ -109,7 +109,8 @@ Boolean DarwinInjector
 		 char const* remoteUserName,
 		 char const* remotePassword,
 		 char const* sessionAuthor,
-		 char const* sessionCopyright) {
+		 char const* sessionCopyright,
+		 int timeout) {
   char* sdp = NULL;
   char* url = NULL;
   Boolean success = False; // until we learn otherwise
@@ -186,9 +187,9 @@ Boolean DarwinInjector
     Boolean announceSuccess;
     if (remoteUserName[0] != '\0' || remotePassword[0] != '\0') {
       announceSuccess
-	= fRTSPClient->announceWithPassword(url, sdp, remoteUserName, remotePassword);
+	= fRTSPClient->announceWithPassword(url, sdp, remoteUserName, remotePassword, timeout);
     } else {
-      announceSuccess = fRTSPClient->announceSDPDescription(url, sdp);
+      announceSuccess = fRTSPClient->announceSDPDescription(url, sdp, NULL, timeout);
     }
     if (!announceSuccess) break;
 
@@ -232,7 +233,7 @@ Boolean DarwinInjector
   } while (0);
 
   delete[] sdp;
-  delete[] url; 
+  delete[] url;
   return success;
 }
 
@@ -278,7 +279,7 @@ SubstreamDescriptor::SubstreamDescriptor(RTPSink* rtpSink,
   char const* auxSDPLine = fRTPSink->auxSDPLine();
   if (auxSDPLine == NULL) auxSDPLine = "";
   unsigned auxSDPLineSize = strlen(auxSDPLine);
-  
+
   char const* const sdpFmt =
     "m=%s 0 RTP/AVP %u\r\n"
     "%s" // "a=rtpmap:" line (if present)
